@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod, abstractproperty
 from cicada.analysis.cicada_analysis_arguments_handler import AnalysisArgumentsHandler
 from cicada.analysis.cicada_analysis_nwb_wrapper import CicadaAnalysisNwbWrapper
-from cicada.preprocessing.utils import class_name_to_file_name, path_leaf
+from cicada.preprocessing.utils import class_name_to_module_name, path_leaf
 import importlib
 import PyQt5.QtCore as Core
 from qtpy.QtCore import QThread
@@ -112,8 +112,10 @@ class CicadaAnalysis(ABC):
         return identifiers
 
     def copy(self):
-
-        module_name = 'cicada.analysis.' + class_name_to_file_name(self.__class__.__name__)
+        # print(f"copy self.__module__ {self.__module__}")
+        # print(f"copy sys.modules[self.__module__] {sys.modules[self.__module__]}")
+        # print(f"copy sys.modules[self.__module__].__file__ {sys.modules[self.__module__].__file__}")
+        module_name = self.__module__
         module = importlib.import_module(module_name)
         new_class = getattr(module, self.__class__.__name__)
         new_object = new_class()
@@ -180,6 +182,11 @@ class CicadaAnalysis(ABC):
 
         # creating a new AnalysisArgumentsHandler instance
         self.analysis_arguments_handler = AnalysisArgumentsHandler(cicada_analysis=self)
+
+        if (self.long_description is not None) and isinstance(self.long_description, str) and \
+                (len(self.long_description.strip()) > 0):
+            self.add_analysis_description_for_gui(description=self.long_description)
+
         # we order_index at 1000 for it to be displayed at the end
         default_results_path = None
         mandatory = True
@@ -193,6 +200,7 @@ class CicadaAnalysis(ABC):
 
         self.add_argument_for_gui(**results_path_arg)
 
+
     def get_data_to_analyse(self):
 
         """
@@ -248,6 +256,23 @@ class CicadaAnalysis(ABC):
         else:
             pass
 
+    def add_analysis_description_for_gui(self, description):
+        """
+        Add a description that will be displayed as a widget on top of the arguments list
+        Args:
+            description:
+
+        Returns:
+
+        """
+
+        analysis_descr_arg = {"arg_name": "analysis_description", "value_type": "text",
+                              "short_description": "Analysis description",
+                              "default_value": description,
+                              "read_only": True, "mandatory": True, "order_index": 0}
+
+        self.add_argument_for_gui(**analysis_descr_arg)
+
     def add_ci_movie_arg_for_gui(self, long_description=None):
         """
         Will add an argument for gui, named ci_movie that will list all calcium imaging available for each session
