@@ -47,8 +47,10 @@ class AnalysisArgument:
                 RuntimeError: wrapped C/C++ object of type SliderWidget has been deleted
 
         """
-
-        if getattr(self, "value_type", None) == "int":
+        if getattr(self, "value_type", None) == "text":
+            self._widget = TextEditWidget(analysis_arg=self)
+            return self._widget
+        elif getattr(self, "value_type", None) == "int":
             if hasattr(self, "min_value") and hasattr(self, "max_value"):
                 self._widget = SliderWidget(analysis_arg=self)
                 return self._widget
