@@ -1,6 +1,7 @@
 from cicada.analysis.cicada_analysis_format_wrapper import CicadaAnalysisFormatWrapper
 from pynwb.ophys import ImageSegmentation, TwoPhotonSeries, Fluorescence
 from pynwb.image import ImageSeries
+from pynwb.base import TimeSeries
 import os
 from pynwb import NWBHDF5IO
 import numpy as np
@@ -92,6 +93,56 @@ class CicadaAnalysisNwbWrapper(CicadaAnalysisFormatWrapper):
         # it could be empty, but if it would matter, it should have been check by method check_data in CicadaAnalysis
         return segmentation_dict
 
+    def get_signals_info(self):
+        """
+
+            Returns: a dict that for each step till the TimeSeries name represents the different option.
+            First dict will have as keys the name of the modules, then for each modules the value will be
+            the name of the TimeSeries representing the signal
+
+        """
+        signal_dict = dict()
+        for name_mod, mod in self._nwb_data.modules.items():
+            signal_dict[name_mod] = []
+            no_keys_added = True
+            for key, value in mod.data_interfaces.items():
+                # we want to check that the object in Module is an Instance of ImageSegmentation
+                if isinstance(value, TimeSeries):
+                    signal_dict[name_mod].append(key)
+                    no_keys_added = False
+            if no_keys_added:
+                del signal_dict[name_mod]
+
+        return signal_dict
+
+    def get_signal_by_keyword(self, keyword, exact_keyword=False):
+        """
+        Look for a signal with this keyword. Returns the first instance found that matches it.
+        Args:
+            keyword: (str)
+            exact_keyword: (bool) if True, the name of the TimeSeries representing the signal should be the same
+            as keyword, otherwise keyword should be in the name of the TimeSeries
+
+        Returns: a two 1d array representing a signal and its timestamps.
+            If no sginal with this keyword found, return None, None
+
+        """
+        for name_mod, mod in self._nwb_data.modules.items():
+            for key, value in mod.data_interfaces.items():
+                # we want to check that the object in Module is an Instance of ImageSegmentation
+                if isinstance(value, TimeSeries):
+                    valid_key = False
+                    if exact_keyword:
+                        if keyword == key:
+                            valid_key = True
+                    else:
+                        if keyword in key:
+                            valid_key = True
+                    if valid_key:
+                        return np.array(value.data), np.array(value.timestamps)
+
+        return None, None
+
     def get_roi_response_serie_data(self, keys):
         """
 
