@@ -2,9 +2,11 @@ from qtpy.QtWidgets import *
 from qtpy.QtCore import QAbstractItemModel, QModelIndex, Qt
 from qtpy import QtCore, QtGui
 from sortedcontainers import SortedDict
-from cicada.preprocessing.utils import class_name_to_file_name
+from cicada.preprocessing.utils import class_name_to_module_name, module_name_to_class_name
 from cicada.gui.cicada_analysis_parameters_gui import AnalysisPackage
 import importlib
+import glob
+import os
 from time import time
 import numpy as np
 
@@ -569,42 +571,32 @@ class AnalysisTreeApp(QWidget):
 
         self.show()
 
+    # TODO: Create a function in order to update the tree after initialization with new analyses
     def create_tree_model(self):
         """
         Create the tree model
         Returns: the tree model, an instance of QAnalysisTreeModel
 
         """
-        # TODO: a system that list the Analysis Function available in the pipeline
-        #  + a system that either read a yaml file or a dir and load automatically analysis function
+        # TODO: a system that either read a yaml file or a dir and load automatically analysis function
         # TODO: don't load classed if the method get_params_for_gui return None ?
-        analysis_class_names = ["CicadaHubsAnalysis", "CicadaConnectivityGraph", "CicadaConnectivityGraphsDescription",
-                                "CicadaPsthAnalysis", "CicadaCellsMapAnalysis",
-                                "CicadaSplittingCellsAnalysis",
-                                "CicadaDisplayRasterAnalysis",
-                                "CicadaDeepCinacPredictionAnalysis", "CicadaTimeCorrelationGraphAnalysis",
-                                "CicadaSeqGraphAnalysis", "CicadaSeqnmfAnalysis",
-                                "CicadaSeqMalvacheAnalysis", "CicadaAssembliesMalvacheAnalysis",
-                                "CicadaAssembliesRussoAnalysis", "CicadaSpotDisClustAnalysis",
-                                "CicadaAssembliesIcaCsAnalysis", "CicadaAssembliesIcaMpAnalysis",
-                                "CicadaAssembliesSvdAnalysis", "CicadaAssembliesSgcAnalysis",
-                                "CicadaAssembliesPromaxCsAnalysis", "CicadaAssembliesPromaxMpAnalysis",
-                                "CicadaAssembliesGonzalezAnalysis", "CicadaAssembliesTavoniAnalysis",
-                                "CicadaAssembliesCoreAnalysis", "CicadaTransientFrequencyAnalysis",
-                                "CicadaTransientDurationAnalysis", "CicadaTransientAmplitudeAnalysis",
-                                "CicadaSceDescritpionAnalysis",
-                                "CicadaCellAssVsIntervalsAnalysis", "CicadaTransientsVsIntervalsAnalysis",
-                                "CicadaActivityIntervalsRatioAnalysis", "CicadaTripleSeqPlotAnalysis",
-                                "CicadaBehaviorQuantificationAnalysis"]
+        # https://stackoverflow.com/questions/67631/how-to-import-a-module-given-the-full-path
+
+        modules = glob.glob(os.path.join(os.path.dirname(__file__), "..", "analysis", "ci_analyses", "*.py"))
+        all_modules = [os.path.basename(f)[:-3] for f in modules if os.path.isfile(f) and not f.startswith(".")
+                       and not f.endswith('__init__.py')]
+        all_classes = [module_name_to_class_name(m) for m in all_modules]
+
+        # module_name_to_class_name(module_name)
         analysis_instances = []
-        for class_name in analysis_class_names:
-            module_name = class_name_to_file_name(class_name=class_name)
-            module_imported = importlib.import_module("cicada.analysis." + module_name)
+        for class_index, class_name in enumerate(all_classes):
+            # module_name = class_name_to_module_name(class_name=class_name)
+            module_name = all_modules[class_index]
+            module_imported = importlib.import_module("cicada.analysis.ci_analyses." + module_name)
             class_instance = getattr(module_imported, class_name)
             # class_instance = getattr(test_cicada_test_paul, class_name)
             analysis_instances.append(class_instance(config_handler=self.config_handler))
 
-
         # it's a dict that contains other dicts.
         # dict key represents the name of the family. Instances in the dict with "zzz" are the ones
         # with no family
