@@ -1,6 +1,6 @@
 from qtpy.QtWidgets import *
 from qtpy import QtCore, QtGui
-from .cicada_exploratory_widgets import BehaviorVideoWidget, CiVideoWidget, CiVideoConfigWidget
+from .cicada_exploratory_widgets import BehaviorVideoWidget, CiVideoWidget, CiVideoConfigWidget, SignalWidget
 from .cicada_time_intervals import TimeIntervalsManager
 from cicada.utils.display.cells_map_utils import CellsCoord
 from cicada.utils.misc import get_tree_dict_as_a_list
@@ -108,7 +108,7 @@ class ExploratoryMainWindow(QMainWindow):
         # self.createMenus()
         self.object_created = []
         self.labels = []
-        self.setWindowTitle("CICADA BADASS GUI")
+        self.setWindowTitle(f"CICADA BADASS GUI - {self.data_to_explore.identifier}")
 
         screenGeometry = QApplication.desktop().screenGeometry()
         # making sure the window is not bigger than the dimension of the screen
@@ -147,6 +147,11 @@ class ExploratoryMainWindow(QMainWindow):
         if event.key() == QtCore.Qt.Key_Minus or event.key() == QtCore.Qt.Key_Down:
             self.central_widget.change_timestamp_step(increment=False)
         if event.key() == QtCore.Qt.Key_S:
+            if self.central_widget.time_intervals_manager.config_widget.ti_start is None:
+                self.central_widget.time_intervals_manager.config_widget.mark_ti_start()
+            else:
+                self.central_widget.time_intervals_manager.config_widget.mark_ti_stop()
+        if event.key() == QtCore.Qt.Key_P:
             self.central_widget.ci_video_widget.switch_surprise_mfh()
             for behavior_video_widget in self.central_widget.behavior_video_widgets:
                 behavior_video_widget.switch_surprise_mfh()
@@ -229,7 +234,7 @@ class ExploratoryCentralWidget(QWidget):
         self.behaviour_video_layout.addWidget(self.ci_video_widget)
         self.behaviour_video_layout.addStretch(1)
         behaviors_movie_time_stamps_dict = self.data_to_explore.get_behaviors_movie_time_stamps()
-        print(f"behaviors_movie_time_stamps_dict {list(behaviors_movie_time_stamps_dict.keys())}")
+        # print(f"behaviors_movie_time_stamps_dict {list(behaviors_movie_time_stamps_dict.keys())}")
         self.behavior_video_widgets = []
         for key_behavior, video_file_name in behavior_movies_dict.items():
             # key_behavior looks like: "behavior_cam_23109588"
@@ -292,6 +297,27 @@ class ExploratoryCentralWidget(QWidget):
         self.h_layout_widgets.addLayout(self.behaviour_video_layout)
         self.main_layout.addLayout(self.h_layout_widgets)
 
+        # ----------------------------------
+        #       Signal widgets
+        # ----------------------------------
+
+        emg_data, emg_timestamps = self.data_to_explore.get_signal_by_keyword(keyword="emg", exact_keyword=False)
+        self.emg_widget = None
+        self.signal_widgets = []
+        if emg_data is not None:
+            # TODO: See to downsample the signal
+            self.emg_widget = SignalWidget(data_to_explore=self.data_to_explore,
+                                           signal_data=emg_data,
+                                           timestamps=emg_timestamps, current_timestamp=self.min_timestamp,
+                                           min_timestamp=self.min_timestamp,
+                                           max_timestamp=self.max_timestamp,
+                                           parent=self,
+                                           go_to_timestamp_fct=self.go_to_timestamp,
+                                           main_window=exploratory_main_window,
+                                           to_connect_to_main_window=True)
+            self.main_layout.addWidget(self.emg_widget)
+            self.signal_widgets.append(self.emg_widget)
+
         # ----------------------------------
         #       Time Intervals widgets
         # ----------------------------------
@@ -302,6 +328,7 @@ class ExploratoryCentralWidget(QWidget):
                                                            current_timestamp=self.current_timestamp,
                                                            main_window=exploratory_main_window, parent=self,
                                                            go_to_timestamp_fct=self.go_to_timestamp)
+        self.time_intervals_manager.link_x_view(widgets_to_link=self.signal_widgets)
         time_invertvals_layout.addWidget(self.time_intervals_manager.get_main_widget())
         time_invertvals_layout.addWidget(self.time_intervals_manager.get_config_widget())
 
@@ -402,6 +429,8 @@ class ExploratoryCentralWidget(QWidget):
     def go_to_timestamp(self, timestamp, from_line_moved=False):
         for behavior_video_widget in self.behavior_video_widgets:
             behavior_video_widget.set_current_timestamp(timestamp=timestamp)
+        if self.emg_widget is not None:
+            self.emg_widget.set_current_timestamp(timestamp=timestamp)
         # self.behavior_video_widget_2.set_current_timestamp(timestamp=timestamp)
         self.ci_video_widget.set_current_timestamp(timestamp=timestamp)
         self.time_intervals_manager.set_current_timestamp(timestamp=timestamp, from_line_moved=from_line_moved)
