@@ -45,18 +45,18 @@ class ExploratoryWidgetModel(ABC):
         if self.main_window and self.to_connect_to_main_window:
             self.main_window.keyPressEvent(event=event)
 
-    @abstractmethod
-    def get_corresponding_frame_index(self, timestamp):
-        """
-        Return the frame index corresponding to this timestamp.
-        If value is negative or > to the number of frames, it means no frame matches
-        Args:
-            timestamp:
-
-        Returns:
-
-        """
-        pass
+    # @abstractmethod
+    # def get_corresponding_frame_index(self, timestamp):
+    #     """
+    #     Return the frame index corresponding to this timestamp.
+    #     If value is negative or > to the number of frames, it means no frame matches
+    #     Args:
+    #         timestamp:
+    #
+    #     Returns:
+    #
+    #     """
+    #     pass
 
     @abstractmethod
     def set_current_timestamp(self, timestamp):
@@ -410,7 +410,6 @@ class RoisComboBoxesLayout(QHBoxLayout):
 
         self.ci_video_widget.update_current_rois(new_rois=new_rois, colors=colors)
 
-
 class CiVideoWidget(ExploratoryWidgetModel, pg.GraphicsLayoutWidget, metaclass=GraphicsLayoutMeta):
     """
     Used to display Calcium Imaging movie
@@ -825,6 +824,109 @@ class MyViewBox(pg.ViewBox):
             pg.ViewBox.mouseDragEvent(self, ev)
 
 
+class SignalWidget(ExploratoryWidgetModel, pg.PlotWidget, metaclass=PgMeta):
+    """
+    Used to display a 1d signal
+    """
+
+    def __init__(self, data_to_explore, signal_data, timestamps, min_timestamp, max_timestamp,
+                 go_to_timestamp_fct,
+                 current_timestamp=0,
+                 main_window=None, to_connect_to_main_window=True, parent=None):
+        """
+
+        Args:
+            data_to_explore: Wrapper data format
+            signal_data:
+            timestamps:  np.array of float, give the timestamp of each frame of the movie
+            min_timestamp:
+            max_timestamp:
+            go_to_timestamp_fct: fct that take as first argument a timestamp, should be called if the current_timestamp
+            changed
+            current_timestamp: timestamp to display (the closest will be displayed)
+            main_window:
+            to_connect_to_main_window:
+            parent:
+        """
+        ExploratoryWidgetModel.__init__(self, data_to_explore=data_to_explore, main_window=main_window,
+                                        to_connect_to_main_window=to_connect_to_main_window)
+        pg.GraphicsLayoutWidget.__init__(self)
+
+        self.view_box = MyViewBox()
+        pg.PlotWidget.__init__(self, parent=parent, viewBox=self.view_box)
+        # allows the widget to be expanded in both axis
+        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        # 230 is the height, the width 300 here doesn't really matter as it is expending
+        self.setSceneRect(0, 0, 300, 230)
+        self.main_window = main_window
+        self.min_timestamp = min_timestamp
+        self.max_timestamp = max_timestamp
+        self.current_timestamp = current_timestamp
+        self.timestamps = timestamps
+        self.signal_data = signal_data
+        self.go_to_timestamp_fct = go_to_timestamp_fct
+
+        self.data_to_explore = data_to_explore
+
+        self.pg_plot = self.getPlotItem()
+        # self.invertY(True)
+        # hide the left axis, as the label of each tag is displayed on the line
+        self.pg_plot.hideAxis(axis='left')
+        self.pg_plot.hideAxis(axis='bottom')
+        # view_box = pg_plot.getViewBox()
+        y_min = np.min(self.signal_data)
+        y_max = np.max(self.signal_data)
+        range_signal = y_max - y_min
+        # print(f"y_min {y_min}, y_max {y_max}, range_signal {range_signal}")
+        self.view_box.setLimits(xMin=self.min_timestamp - 1, xMax=self.max_timestamp + 1,
+                                yMin=y_min - (range_signal / 5), yMax=y_max)
+        # range of the plot that can be manipulated
+        self.pg_plot.setXRange(self.min_timestamp, self.max_timestamp)
+        self.pg_plot.setYRange(y_min - (range_signal / 5), y_max)
+        self.pg_plot.setAspectLocked(True)
+        # (0,0,255) == "blue"
+        color_pen = (0, 0, 255) # dark blue
+        color_hover_pen = (100, 149, 237) # lighh blue
+        self.current_timestamp_marker = FiniteLine(pos=[self.current_timestamp, 0],
+                                                   angle=90, finite_values=None, pen=color_pen, movable=True,
+                                                   bounds=[self.min_timestamp, self.max_timestamp],
+                                                   hoverPen=color_hover_pen, label=None, labelOpts=None,
+                                                   name=None, int_rounding=False,
+                                                   new_line_pos_callback=self.line_moved,
+                                                   first_line=False,
+                                                   time_interval=None)
+        self.pg_plot.addItem(item=self.current_timestamp_marker)
+
+        # ploting the signal, with red pen
+        self.pg_plot.plot(self.timestamps, self.signal_data, pen=(255, 0, 0))
+
+    def set_current_timestamp(self, timestamp, from_line_moved=False):
+        self.current_timestamp = timestamp
+        self.current_timestamp_marker.setPos(pos=[timestamp, 0])
+
+    def get_displayed_range(self):
+        """
+        Return the range of the displayed values in the plot
+        Returns:
+
+        """
+        return self.pg_plot.getViewBox().viewRange()
+
+    def line_moved(self, new_pos, first_value, time_interval):
+        """
+        The finite line has been moved. We change the frame displayed in consequence
+        Args:
+            new_pos:
+
+        Returns:
+
+        """
+        self.go_to_timestamp_fct(timestamp=new_pos)
+
+    def link_to_view(self, view_to_link):
+        self.view_box.setXLink(view=view_to_link)
+
+
 class TimeIntervalsMainWidget(ExploratoryWidgetModel, pg.PlotWidget, metaclass=PgMeta):
     """
     Module that will display the different w intervals along the frames
