@@ -52,6 +52,18 @@ class TimeIntervalsManager:
 
         self.create_intervals_from_data_to_explore()
 
+    def link_x_view(self, widgets_to_link):
+        """
+        Link the x view of the time interval widget to some other widgets
+        Args:
+            widgets_to_link: list of widgets
+
+        Returns:
+
+        """
+        for widget_to_link in widgets_to_link:
+            widget_to_link.link_to_view(view_to_link=self.main_widget.view_box)
+
     def set_current_timestamp(self, timestamp, from_line_moved=False):
         """
         Change the timestamp in  elements of the IntervalManager
