@@ -1,6 +1,6 @@
 import yaml
 import os
-from cicada.preprocessing.utils import class_name_to_file_name, get_subfiles, get_subdirs
+from cicada.preprocessing.utils import class_name_to_module_name, get_subfiles, get_subdirs
 import importlib
 from pynwb import NWBHDF5IO
 from pynwb import NWBFile
@@ -309,7 +309,7 @@ def create_convert_class(class_name, config_dict, converter_dict, nwb_file, yaml
     """
 
     # Get classname then instantiate it
-    module_name = class_name_to_file_name(class_name=class_name)
+    module_name = class_name_to_module_name(class_name=class_name)
     module_imported = importlib.import_module("cicada.preprocessing." + module_name)
     class_instance = getattr(module_imported, class_name)
     converter = class_instance(nwb_file)
@@ -380,15 +380,31 @@ def create_convert_class(class_name, config_dict, converter_dict, nwb_file, yaml
                 if (file_name.endswith("mat") or file_name.endswith("npz")) and \
                         config_dict[arg].get("value"):
                     if file_name.endswith("npz"):
+                        file_name = os.path.basename(arg_dict[arg])
                         arg_dict[arg] = np.load(arg_dict[arg])
-                        arg_dict[arg] = arg_dict[arg][config_dict[arg].get("value")]
+                        try:
+                            arg_dict[arg] = arg_dict[arg][config_dict[arg].get("value")]
+                        except KeyError:
+                            raise Exception(f'{config_dict[arg].get("value")} is not a valid key of {file_name}. '
+                                            f'Valid keys are: {list(arg_dict[arg].keys())}')
                     else:
                         arg_dict[arg] = hdf5storage.loadmat(arg_dict[arg])
                         # print(f"arg_dict[arg].keys() {arg_dict[arg].keys()}")
-                        arg_dict[arg] = arg_dict[arg][config_dict[arg].get("value")][0]
+                        # print(f'config_dict[arg].get("value") {config_dict[arg].get("value")}')
+                        # print(f'arg_dict[arg][config_dict[arg].get("value")] '
+                        #       f'{arg_dict[arg][config_dict[arg].get("value")][0][0][0][0]}')
+                        if len(arg_dict[arg][config_dict[arg].get("value")]) == 1:
+                            arg_dict[arg] = arg_dict[arg][config_dict[arg].get("value")][0]
+                            # if len(arg_dict[arg]) == 1:
+                            #     arg_dict[arg] = arg_dict[arg][0][0][0][0][0]
+                                # print(f'arg_dict[arg] '
+                                #       f'{arg_dict[arg]}')
+                        else:
+                            arg_dict[arg] = arg_dict[arg][config_dict[arg].get("value")]
+                        # arg_dict[arg] = arg_dict[arg][config_dict[arg].get("value")][0]
                     # another option will be to pass the file_name + the value field like this:
                     # arg_dict[arg] = [arg_dict[arg]] + list(config_dict[arg].get("value"))
-                    arg_dict[arg] = arg_dict[arg]
+                    # arg_dict[arg] = arg_dict[arg]
             # If no file found, put the argument at None
             else:
                 arg_dict[arg] = None
