@@ -5,7 +5,7 @@ import pyabf
 import math
 import matplotlib.pyplot as plt
 from pynwb.base import TimeSeries
-from cicada.preprocessing.utils import get_continous_time_periods, merging_time_periods, class_name_to_file_name
+from cicada.preprocessing.utils import get_continous_time_periods, merging_time_periods, class_name_to_module_name
 
 class ConvertAbfToNWB(ConvertToNWB):
     """Class to convert ABF data to NWB """
@@ -463,7 +463,7 @@ class ConvertAbfToNWB(ConvertToNWB):
                 movies_sampling_rate.append(
                     1 / ((segment_time_in_ms / 1000) / (len(self.ci_frames_indices) - (self.gap_indices[-1] + 1))))
                 self.sampling_rate_calcium_imaging = np.mean(movies_sampling_rate)
-                print(f"movie_sampling_rate {self.sampling_rate_calcium_imaging} Hz")
+            print(f"movie_sampling_rate {self.sampling_rate_calcium_imaging} Hz")
 
             # given the conversion factor to get the timestamps in sec
             # we record them in ms to have a better precision
