@@ -33,11 +33,12 @@ def build_connectivity_graphs(raster_dur, sampling_rate, time_delay=500, save_gr
     # look neuron by neuron, at each spike and make a pair wise for each other neurons according to the spike
     # distribution around 500ms before and after. If the distribution is not uniform then we look where is the max
     # and we add it to n_out or n_in if before or after. If it is at the same time, then we don't add it.
-    n_in_dict = dict()
-    n_out_dict = dict()
+
+    # building graph using Networkx package
+    # DiGraph means directed graph
+    connectivity_graph = nx.DiGraph()
+    connectivity_graph.add_nodes_from(np.arange(n_cells))
     for neuron in np.arange(n_cells):
-        n_in_dict[neuron] = dict()
-        n_out_dict[neuron] = dict()
         neurons_to_consider = np.arange(n_cells)
         mask = np.ones(n_cells, dtype="bool")
         mask[neuron] = False
@@ -67,7 +68,6 @@ def build_connectivity_graphs(raster_dur, sampling_rate, time_delay=500, save_gr
             mask_end = mask_start + (max_limit - min_limit) + 1
             # print(f"")
             mask[:, mask_start:mask_end] = spike_nums_to_use[:, min_limit:(max_limit + 1)] > 0
-            print(f"mask {mask}")
             distribution_array_2_d[mask] = distribution_array_2_d[mask] + 1
 
         # going neuron by neuron
@@ -86,65 +86,42 @@ def build_connectivity_graphs(raster_dur, sampling_rate, time_delay=500, save_gr
                 ks, p_ks = stats.kstest(distribution_for_test, stats.randint.cdf,
                                         args=(np.min(distribution_for_test),
                                               np.max(distribution_for_test)))
+
                 is_normal_distribution = p_value >= 0.05
                 is_uniform_distribution = p_ks >= 0.05
                 # if the distribution is normal or uniform, we skip it
                 if is_normal_distribution or is_uniform_distribution:
                     continue
                 else:
-                    plt.hist(distribution_array)
-                    plt.show()
                     n_in_sum = np.sum(distribution_array[:event_index])
                     n_out_sum = np.sum(distribution_array[(event_index + 1):])
                     if n_in_sum > n_out_sum:
-                        n_in_dict[neuron][neuron_to_consider] = 1
-                        # self.n_in_matrix[neuron][neuron_to_consider] = 1
-                    else:
-                        n_out_dict[neuron][neuron_to_consider] = 1
-                        # self.n_out_matrix[neuron][neuron_to_consider] = 1
+                        connectivity_graph.add_edge(neuron_to_consider, neuron)
+                    if n_in_sum < n_out_sum:
+                        connectivity_graph.add_edge(neuron, neuron_to_consider)
             else:
                 continue
 
-    # building graph using Networkx package
-    # DiGraph means directed graph
-    graph_in = nx.DiGraph()
-    graph_in.add_nodes_from(np.arange(n_cells))
-    graph_out = nx.DiGraph()
-    graph_out.add_nodes_from(np.arange(n_cells))
-
-    for cell, cells_connected in n_in_dict.items():
-        for cell_connected in cells_connected.keys():
-            graph_in.add_edge(cell, cell_connected)
-
-    for cell, cells_connected in n_out_dict.items():
-        for cell_connected in cells_connected.keys():
-            graph_out.add_edge(cell, cell_connected)
-
     if save_graphs is True and path_results is not None:
         time_str = ""
         if with_timestamp_in_file_name:
             time_str = datetime.now().strftime("%Y_%m_%d.%H-%M-%S")
 
         if not with_timestamp_in_file_name:
-            nx.write_graphml(graph_in, os.path.join(f'{path_results}', f'{filename}_in.graphml'))
 
-            nx.write_graphml(graph_out, os.path.join(f'{path_results}', f'{filename}_out.graphml'))
+            nx.write_graphml(connectivity_graph, os.path.join(f'{path_results}', f'{filename}.graphml'))
 
-            nx.write_gexf(graph_in, os.path.join(f'{path_results}', f'{filename}_in.gexf'))
-
-            nx.write_gexf(graph_out, os.path.join(f'{path_results}', f'{filename}_out.gexf'))
+            nx.write_gexf(connectivity_graph, os.path.join(f'{path_results}', f'{filename}.gexf'))
 
         else:
 
-            nx.write_graphml(graph_in, os.path.join(f'{path_results}', f'{filename}_in_{time_str}.graphml'))
+            nx.write_graphml(connectivity_graph, os.path.join(f'{path_results}', f'{filename}.graphml'))
 
-            nx.write_graphml(graph_out, os.path.join(f'{path_results}', f'{filename}_out_{time_str}.graphml'))
+            nx.write_gexf(connectivity_graph, os.path.join(f'{path_results}', f'{filename}.gexf'))
 
-            nx.write_gexf(graph_in, os.path.join(f'{path_results}', f'{filename}_in_{time_str}.gexf'))
+    # return graph_in, graph_out, connectivity_graph
 
-            nx.write_gexf(graph_out, os.path.join(f'{path_results}', f'{filename}_out_{time_str}.gexf'))
-
-    return graph_in, graph_out
+    return connectivity_graph
 
 
 def plot_graph(graph, with_fa2=False, randomized_positions=False, filename=None, iterations=2000,
@@ -235,10 +212,11 @@ def plot_graph(graph, with_fa2=False, randomized_positions=False, filename=None,
         plt.close()
 
 
-def plot_connectivity_graphs(session_id_list, connectivity_type=None, graph_files_path=None, background_color=None,
+def plot_connectivity_graphs(session_id_list, graph_files_path=None, background_color=None,
                              node_color=None, edge_color=None,
                              size_fig=None,
-                             save_formats=None, save_figure=False, path_results=None, with_timestamp_in_file_name=False):
+                             save_formats=None, save_figure=False, path_results=None,
+                             with_timestamp_in_file_name=False, celltype=None, time_delay=None):
     # qualitative 12 colors : http://colorbrewer2.org/?type=qualitative&scheme=Paired&n=12
     # + 11 diverting
     colors = ['#a6cee3', '#1f78b4', '#b2df8a', '#33a02c', '#fb9a99', '#e31a1c', '#fdbf6f',
@@ -268,21 +246,14 @@ def plot_connectivity_graphs(session_id_list, connectivity_type=None, graph_file
         ax.set_facecolor(background_color)
         axes[ax_index].set_facecolor(background_color)
         session_identifier = session_id_list[ax_index]
-        filename = session_identifier + "_connectivity_graphs"
+        filename = session_identifier + "_connectivity_graphs_" + str(time_delay) + "ms_" + celltype
         node_color = node_color_list[ax_index]
 
-        path_to_graph_in_graphml = os.path.join(f'{graph_files_path}', f'{filename}_in.graphml')
-        path_to_graph_out_graphml = os.path.join(f'{graph_files_path}', f'{filename}_out.graphml')
-        graph_in = nx.read_graphml(path=path_to_graph_in_graphml, node_type=int)
-        graph_out = nx.read_graphml(path=path_to_graph_out_graphml, node_type=int)
-        if connectivity_type == "in":
-            graph_to_plot = graph_in
-            name = "_connectivity_graphs" + "_in"
-        else:
-            graph_to_plot = graph_out
-            name = "_connectivity_graphs" + "_out"
+        path_to_graph_graphml = os.path.join(f'{graph_files_path}', f'{filename}.graphml')
+        connectivity_graph = nx.read_graphml(path=path_to_graph_graphml, node_type=int)
+        name = "connectivity_graphs_" + celltype
 
-        plot_graph(graph=graph_to_plot, with_fa2=False, randomized_positions=True, filename=name, iterations=2000,
+        plot_graph(graph=connectivity_graph, with_fa2=False, randomized_positions=True, filename=name, iterations=2000,
                    node_color=node_color, edge_color=edge_color, background_color=background_color,
                    cmap=None, node_size=10,
                    with_labels=False, title=session_identifier, ax_to_use=ax,
@@ -438,7 +409,7 @@ def detect_hub_cells(graphs_to_analyse, cell_connectivity_threshold=5,
                 cells_selected_s2.append(cell)
         if len(cells_selected_s2) == 0:
             if verbose:
-                print(f"Failed at step 2: no cell in the top {top_connected_cells}% of higly connected cells")
+                print(f"Failed at step 2: no cell in the top {top_connected_cells}% of highly connected cells")
             continue
 
         # step 3
